@@ -76,6 +76,7 @@ describe 'horizon' do
           "    'enable_security_group': True,",
           "    'enable_vpn': False,",
           'API_RESULT_LIMIT = 1000',
+          'DROPDOWN_MAX_ITEMS = 30',
           'TIME_ZONE = "UTC"',
           'COMPRESS_OFFLINE = True',
           "FILE_UPLOAD_TEMP_DIR = '/tmp'",
@@ -111,6 +112,7 @@ describe 'horizon' do
           :django_debug                   => true,
           :site_branding                  => 'mysite',
           :api_result_limit               => 4682,
+          :dropdown_max_items             => 123,
           :compress_offline               => false,
           :hypervisor_options             => {'can_set_mount_point' => false, 'can_set_password' => true },
           :cinder_options                 => {'enable_backup' => true },
@@ -198,6 +200,7 @@ describe 'horizon' do
           'OPENSTACK_ENDPOINT_TYPE = "internalURL"',
           'SECONDARY_ENDPOINT_TYPE = "ANY-VALUE"',
           'API_RESULT_LIMIT = 4682',
+          'DROPDOWN_MAX_ITEMS = 123',
           'TIME_ZONE = "Asia/Shanghai"',
           "AVAILABLE_THEMES = [",
           "  ('default', 'Default', 'themes/default'),",
@@ -249,6 +252,23 @@ describe 'horizon' do
       it { is_expected.to contain_exec('refresh_horizon_django_compress') }
     end
 
+    context 'with overridden parameters and IPv6 cache_server_ip array' do
+      before do
+        params.merge!({
+          :cache_server_ip => ['fd12:3456:789a:1::1','fd12:3456:789a:1::2'],
+        })
+      end
+
+      it 'generates local_settings.py' do
+        verify_concat_fragment_contents(catalogue, 'local_settings.py', [
+          "        'LOCATION': [ 'inet6:[fd12:3456:789a:1::1]:11211','inet6:[fd12:3456:789a:1::2]:11211', ],",
+        ])
+      end
+
+      it { is_expected.to contain_exec('refresh_horizon_django_cache') }
+      it { is_expected.to contain_exec('refresh_horizon_django_compress') }
+    end
+
     context 'with overridden parameters and cache_server_url' do
       before do
         params.merge!({
